diff PalanthirServer/PalanthirRestApi.h @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents 491a97842e31
children
line wrap: on
line diff
--- a/PalanthirServer/PalanthirRestApi.h	Wed Sep 05 15:38:08 2012 +0200
+++ b/PalanthirServer/PalanthirRestApi.h	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -27,9 +27,9 @@
 #include <set>
 
 
-namespace Palantir
+namespace Palanthir
 {
-  class PalantirRestApi : public HttpHandler
+  class PalanthirRestApi : public HttpHandler
   {
   private:
     typedef std::set<std::string> Modalities;
@@ -68,8 +68,8 @@
                     const std::string& postData);
 
   public:
-    PalantirRestApi(ServerIndex& index,
-                    const std::string& path);
+    PalanthirRestApi(ServerIndex& index,
+                     const std::string& path);
 
     virtual bool IsServedUri(const UriComponents& uri)
     {
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium